@@ -5,6 +5,7 @@
 ################################################################################
 
 
+import os
 import math
 import pandas as pd
 import porems as pms
@@ -18,12 +19,13 @@ class PoreSystem():
         self._site_in = []
         self._site_ex = []
         self._res = 0
+        self._pore_shape = ""
 
 
     ##############
     # Attachment #
     ##############
-    def _siloxane(self, hydro, site_type):
+    def _siloxane(self, hydro, site_type, slx_dist=[0.507-1e-2, 0.507+1e-2]):
         """Attach siloxane bridges using function
         :func:`porems.pore.Pore.siloxane`.
 
@@ -32,25 +34,25 @@ class PoreSystem():
         hydro: float
             Hydroxilation degree in
             :math:`\\frac{\\mu\\text{mol}}{\\text{m}^2}`.
+        slx_dist : list
+            Silicon atom distance to search for parters in proximity
         site_type : string, optional
             Site type - interior **in**, exterior **ex**
         """
-        # Amount
+        # Initialize
         site_list = self._pore.get_sites()
         sites = self._site_in if site_type=="in" else self._site_ex
+        normal = self._normal_in if site_type=="in" else self._normal_ex
 
+        # Amount - Connect two oxygen to one siloxane
         oh = len(sum([site_list[site]["o"] for site in sites], []))
         oh_goal = pms.utils.mumol_m2_to_mols(hydro, self.surface()[site_type])
         amount = round((oh-oh_goal)/2)
 
         # Fill siloxane
         if amount > 0:
-            # Sites and normal vector
-            sites = self._site_in if site_type=="in" else self._site_ex
-            normal = self._normal_in if site_type=="in" else self._normal_ex
-
             # Run attachment
-            mols = self._pore.siloxane(sites, amount, normal, site_type=site_type)
+            mols = self._pore.siloxane(sites, amount, normal, slx_dist=slx_dist, site_type=site_type)
 
             # Add to sorting list
             for mol in mols:
@@ -150,7 +152,7 @@ class PoreSystem():
             Folder link for output
         """
         # Process input
-        self._link = link if link[-1] == "/" else link+"/"
+        link = link if link[-1] == "/" else link+"/"
 
         # Set sort list
         sort_list = sort_list if sort_list else self._sort_list
@@ -262,6 +264,16 @@ class PoreSystem():
         """
         return self._centroid
 
+    def shape(self):
+        """Return the pore shape for analysis using PoreAna.
+
+        Returns
+        -------
+        pore_shape : string
+            Pore shape
+        """
+        return self._pore_shape
+
 
     #########
     # Table #
@@ -296,8 +308,8 @@ class PoreSystem():
         data["Exterior"]["Simulation box xyz-dimensions (nm)"] = "["+form%self.box()[0]+", "+form%self.box()[1]+", "+form%self.box()[2]+"]"
         data["Interior"]["Pore drilling direction"] = "z"
         data["Exterior"]["Pore drilling direction"] = " "
-        data["Interior"]["Surface roughness (nm)"] = form%self.roughness()
-        data["Exterior"]["Surface roughness (nm)"] = form%0.00
+        data["Interior"]["Surface roughness (nm)"] = form%self.roughness()["in"] if "in" in self.roughness() else form%0
+        data["Exterior"]["Surface roughness (nm)"] = form%self.roughness()["ex"] if "ex" in self.roughness() else form%0
 
         for prop_name, values in props.items():
             data["Interior"][prop_name] = values[0]
@@ -389,7 +401,6 @@ class PoreCylinder(PoreSystem):
         # Build pattern
         pattern = pms.BetaCristobalit()
         pattern.generate(size, "z")
-        if res: pattern.exterior()
 
         # Create block
         self._block = pattern.get_block()
@@ -398,8 +409,15 @@ class PoreCylinder(PoreSystem):
 
         # Dice up block
         dice = pms.Dice(self._block, 0.4, True)
-        matrix = pms.Matrix(dice.find_parallel(None, ["Si", "O"], 0.155, 1e-2))
-        if res: oxygen_out = matrix.bound(1)
+        matrix = pms.Matrix(dice.find_parallel(None, ["Si", "O"], [0.155-1e-2, 0.155+1e-2]))
+
+        # Create pore object
+        self._pore = pms.Pore(self._block, matrix)
+        self._pore.set_name("pore")
+
+        # Create exterior
+        if res:
+            self._pore.exterior(pattern.get_gap())
 
         # Carve out shape
         self._centroid = self._block.centroid()
@@ -407,21 +425,21 @@ class PoreCylinder(PoreSystem):
         self._cylinder = pms.Cylinder({"centroid": self._centroid, "central": central, "length": size[2], "diameter": diam-0.5})  # Preperation precaution
         del_list = [atom_id for atom_id, atom in enumerate(self._block.get_atom_list()) if self._cylinder.is_in(atom.get_pos())]
         matrix.strip(del_list)
+        self._pore_shape = "CYLINDER"
 
         # Prepare pore surface
-        self._pore = pms.Pore(self._block, matrix)
-        self._pore.set_name("pore")
         self._pore.prepare()
 
         # Determine sites
-        if res:
-            self._pore.sites(oxygen_out)
-        else:
-            self._pore.sites()
+        self._pore.sites()
         site_list = self._pore.get_sites()
         self._site_in = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="in"]
         self._site_ex = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
 
+        # Save original surface si positions
+        self._si_pos_in = [self._block.pos(site_key) for site_key, site_val in site_list.items() if site_val["type"]=="in"]
+        self._si_pos_ex = [self._block.pos(site_key) for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
+
         # Siloxane bridges
         if hydro[0]:
             self._siloxane(hydro[0], "in")
@@ -547,7 +565,7 @@ class PoreCylinder(PoreSystem):
             Pore diameter after preperation
         """
         # Calculate distance towards central axis of binding site silicon atoms
-        r = [pms.geom.length(pms.geom.vector([self._centroid[0], self._centroid[1], self._block.pos(site)[2]], self._block.pos(site))) for site in self._site_in]
+        r = [pms.geom.length(pms.geom.vector([self._centroid[0], self._centroid[1], pos[2]], pos)) for pos in self._si_pos_in]
 
         # Calculate mean
         r_bar = sum(r)/len(r) if len(r)>0 else 0
@@ -582,14 +600,32 @@ class PoreCylinder(PoreSystem):
         roughness : float
             Surface roughness
         """
-        # Calculate distance towards central axis of binding site silicon atoms
-        r = [pms.geom.length(pms.geom.vector([self._centroid[0], self._centroid[1], self._block.pos(site)[2]], self._block.pos(site))) for site in self._site_in]
+        # Interior
+        ## Calculate distance towards central axis of binding site silicon atoms
+        r_in = [pms.geom.length(pms.geom.vector([self._centroid[0], self._centroid[1], pos[2]], pos)) for pos in self._si_pos_in]
+
+        # Exterior
+        if self._res:
+            ## Create molecules with exterior positions
+            temp_mol = pms.Molecule()
+            for pos in self._si_pos_ex:
+                temp_mol.add("Si", pos)
+            temp_mol.zero()
+            size = temp_mol.get_box()[2]
+
+        ## Calculate distance to boundary
+        r_ex = [pos[2] if pos[2] < size/2 else abs(pos[2]-size) for pos in self._si_pos_ex]
 
         # Calculate mean
-        r_bar = sum(r)/len(r) if len(r)>0 else 0
+        r_bar_in = sum(r_in)/len(r_in) if len(r_in)>0 else 0
+        r_bar_ex = sum(r_ex)/len(r_ex) if len(r_ex)>0 else 0
+
+        # Calculate roughness
+        r_q_in =  math.sqrt(sum([(r_i-r_bar_in)**2 for r_i in r_in])/len(r_in)) if len(r_in)>0 else 0
+        r_q_ex =  math.sqrt(sum([(r_i-r_bar_ex)**2 for r_i in r_ex])/len(r_ex)) if len(r_ex)>0 else 0
 
         # Calculate square root roughness
-        return math.sqrt(sum([(r_i-r_bar)**2 for r_i in r])/len(r)) if len(r)>0 else 0
+        return {"in": r_q_in, "ex": r_q_ex}
 
     def volume(self):
         """Calculate pore volume. This is done by defining a new shape object
@@ -688,7 +724,6 @@ class PoreSlit(PoreSystem):
         # Build pattern
         pattern = pms.BetaCristobalit()
         pattern.generate(size, "z")
-        if res: pattern.exterior()
 
         # Create block
         self._block = pattern.get_block()
@@ -697,8 +732,15 @@ class PoreSlit(PoreSystem):
 
         # Dice up block
         dice = pms.Dice(self._block, 0.4, True)
-        matrix = pms.Matrix(dice.find_parallel(None, ["Si", "O"], 0.155, 1e-2))
-        if res: oxygen_out = matrix.bound(1)
+        matrix = pms.Matrix(dice.find_parallel(None, ["Si", "O"], [0.155-1e-2, 0.155+1e-2]))
+
+        # Create pore object
+        self._pore = pms.Pore(self._block, matrix)
+        self._pore.set_name("pore")
+
+        # Create exterior
+        if res:
+            self._pore.exterior(pattern.get_gap())
 
         # Carve out shape
         self._centroid = self._block.centroid()
@@ -706,21 +748,21 @@ class PoreSlit(PoreSystem):
         self._cuboid = pms.Cuboid({"centroid": self._centroid, "central": central, "length": size[2], "width": size[0], "height": height-0.5})  # Preperation precaution
         del_list = [atom_id for atom_id, atom in enumerate(self._block.get_atom_list()) if self._cuboid.is_in(atom.get_pos())]
         matrix.strip(del_list)
+        self._pore_shape = "SLIT"
 
         # Prepare pore surface
-        self._pore = pms.Pore(self._block, matrix)
-        self._pore.set_name("pore")
         self._pore.prepare()
 
         # Determine sites
-        if res:
-            self._pore.sites(oxygen_out)
-        else:
-            self._pore.sites()
+        self._pore.sites()
         site_list = self._pore.get_sites()
         self._site_in = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="in"]
         self._site_ex = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
 
+        # Save original surface si positions
+        self._si_pos_in = [self._block.pos(site_key) for site_key, site_val in site_list.items() if site_val["type"]=="in"]
+        self._si_pos_ex = [self._block.pos(site_key) for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
+
         # Siloxane bridges
         if hydro[0]:
             self._siloxane(hydro[0], "in")
@@ -846,7 +888,7 @@ class PoreSlit(PoreSystem):
             Pore size after preperation
         """
         # Calculate distance towards central axis of binding site silicon atoms
-        r = [pms.geom.length(pms.geom.vector([self._block.pos(site)[0], self._centroid[1], self._block.pos(site)[2]], self._block.pos(site))) for site in self._site_in]
+        r = [pms.geom.length(pms.geom.vector([pos[0], self._centroid[1], pos[2]], pos)) for pos in self._si_pos_in]
 
         # Calculate mean
         r_bar = sum(r)/len(r) if len(r)>0 else 0
@@ -880,14 +922,32 @@ class PoreSlit(PoreSystem):
         roughness : float
             Surface roughness
         """
-        # Calculate distance towards central axis of binding site silicon atoms
-        r = [pms.geom.length(pms.geom.vector([self._block.pos(site)[0], self._centroid[1], self._block.pos(site)[2]], self._block.pos(site))) for site in self._site_in]
+        # Interior
+        ## Calculate distance towards central axis of binding site silicon atoms
+        r_in = [pms.geom.length(pms.geom.vector([pos[0], self._centroid[1], pos[2]], pos)) for pos in self._si_pos_in]
+
+        # Exterior
+        if self._res:
+            ## Create molecules with exterior positions
+            temp_mol = pms.Molecule()
+            for pos in self._si_pos_ex:
+                temp_mol.add("Si", pos)
+            temp_mol.zero()
+            size = temp_mol.get_box()[2]
+
+        ## Calculate distance to boundary
+        r_ex = [pos[2] if pos[2] < size/2 else abs(pos[2]-size) for pos in self._si_pos_ex]
 
         # Calculate mean
-        r_bar = sum(r)/len(r) if len(r)>0 else 0
+        r_bar_in = sum(r_in)/len(r_in) if len(r_in)>0 else 0
+        r_bar_ex = sum(r_ex)/len(r_ex) if len(r_ex)>0 else 0
+
+        # Calculate roughness
+        r_q_in =  math.sqrt(sum([(r_i-r_bar_in)**2 for r_i in r_in])/len(r_in)) if len(r_in)>0 else 0
+        r_q_ex =  math.sqrt(sum([(r_i-r_bar_ex)**2 for r_i in r_ex])/len(r_ex)) if len(r_ex)>0 else 0
 
         # Calculate square root roughness
-        return math.sqrt(sum([(r_i-r_bar)**2 for r_i in r])/len(r)) if len(r)>0 else 0
+        return {"in": r_q_in, "ex": r_q_ex}
 
     def volume(self):
         """Calculate pore volume. This is done by defining a new shape object
@@ -992,7 +1052,6 @@ class PoreCapsule(PoreSystem):
         # Build pattern
         self._pattern = pms.BetaCristobalit()
         self._pattern.generate(self._size, "z")
-        if res: self._pattern.exterior()
         self._len_cyl = (self._pattern.get_size()[2]-sep-diam)/2
 
         # Create block
@@ -1002,8 +1061,15 @@ class PoreCapsule(PoreSystem):
 
         # Dice up block
         dice = pms.Dice(self._block, 0.4, True)
-        matrix = pms.Matrix(dice.find_parallel(None, ["Si", "O"], 0.155, 1e-2))
-        if res: oxygen_out = matrix.bound(1)
+        matrix = pms.Matrix(dice.find_parallel(None, ["Si", "O"], [0.155-1e-2, 0.155+1e-2]))
+
+        # Create pore object
+        self._pore = pms.Pore(self._block, matrix)
+        self._pore.set_name("pore")
+
+        # Create exterior
+        if res:
+            self._pore.exterior(self._pattern.get_gap())
 
         # Carve out shape
         central = [0, 0, 1]
@@ -1026,20 +1092,21 @@ class PoreCapsule(PoreSystem):
             del_list.extend([atom_id for atom_id, atom in enumerate(self._block.get_atom_list()) if shape.is_in(atom.get_pos())])
         matrix.strip(del_list)
 
+        self._pore_shape = "CAPSULE"
+
         # Prepare pore surface
-        self._pore = pms.Pore(self._block, matrix)
-        self._pore.set_name("pore")
         self._pore.prepare()
 
         # Determine sites
-        if res:
-            self._pore.sites(oxygen_out)
-        else:
-            self._pore.sites()
+        self._pore.sites()
         site_list = self._pore.get_sites()
         self._site_in = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="in"]
         self._site_ex = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
 
+        # Save original surface si positions
+        self._si_pos_in = [self._block.pos(site_key) for site_key, site_val in site_list.items() if site_val["type"]=="in"]
+        self._si_pos_ex = [self._block.pos(site_key) for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
+
         # Siloxane bridges
         if hydro[0]:
             self._siloxane(hydro[0], "in")
@@ -1121,16 +1188,15 @@ class PoreCapsule(PoreSystem):
             Pore diameter after preperation
         """
         # Determine sites in the cylindric part of the pore
-        site_list = []
-        for site in self._site_in:
-            pos = self._block.pos(site)
+        pos_list = []
+        for pos in self._si_pos_in:
             if pos[2] <= self._len_cyl:
-                site_list.append(site)
+                pos_list.append(pos)
             elif pos[2] >= self._pattern.get_size()[2]-self._len_cyl:
-                site_list.append(site)
+                pos_list.append(pos)
 
         # Calculate distance towards central axis of binding site silicon atoms
-        r = [pms.geom.length(pms.geom.vector([self._centroid["block"][0], self._centroid["block"][1], self._block.pos(site)[2]], self._block.pos(site))) for site in site_list]
+        r = [pms.geom.length(pms.geom.vector([self._centroid["block"][0], self._centroid["block"][1], pos[2]], pos)) for pos in pos_list]
 
         # Calculate mean
         r_bar = sum(r)/len(r) if len(r)>0 else 0
@@ -1166,23 +1232,40 @@ class PoreCapsule(PoreSystem):
         roughness : float
             Surface roughness
         """
-        # Determine sites in the cylindric part of the pore
-        site_list = []
-        for site in self._site_in:
-            pos = self._block.pos(site)
+        # Interior
+        ## Determine sites in the cylindric part of the pore
+        pos_list = []
+        for pos in self._si_pos_in:
             if pos[2] <= self._len_cyl:
-                site_list.append(site)
+                pos_list.append(pos)
             elif pos[2] >= self._pattern.get_size()[2]-self._len_cyl:
-                site_list.append(site)
+                pos_list.append(pos)
 
-        # Calculate distance towards central axis of binding site silicon atoms
-        r = [pms.geom.length(pms.geom.vector([self._centroid["block"][0], self._centroid["block"][1], self._block.pos(site)[2]], self._block.pos(site))) for site in site_list]
+        ## Calculate distance towards central axis of binding site silicon atoms
+        r_in = [pms.geom.length(pms.geom.vector([self._centroid["block"][0], self._centroid["block"][1], pos[2]], pos)) for pos in pos_list]
+
+        # Exterior
+        ## Create molecules with exterior positions
+        if self._res:
+            temp_mol = pms.Molecule()
+            for pos in self._si_pos_ex:
+                temp_mol.add("Si", pos)
+            temp_mol.zero()
+            size = temp_mol.get_box()[2]
+
+        ## Calculate distance to boundary
+        r_ex = [pos[2] if pos[2] < size/2 else abs(pos[2]-size) for pos in self._si_pos_ex]
 
         # Calculate mean
-        r_bar = sum(r)/len(r) if len(r)>0 else 0
+        r_bar_in = sum(r_in)/len(r_in) if len(r_in)>0 else 0
+        r_bar_ex = sum(r_ex)/len(r_ex) if len(r_ex)>0 else 0
+
+        # Calculate roughness
+        r_q_in =  math.sqrt(sum([(r_i-r_bar_in)**2 for r_i in r_in])/len(r_in)) if len(r_in)>0 else 0
+        r_q_ex =  math.sqrt(sum([(r_i-r_bar_ex)**2 for r_i in r_ex])/len(r_ex)) if len(r_ex)>0 else 0
 
         # Calculate square root roughness
-        return math.sqrt(sum([(r_i-r_bar)**2 for r_i in r])/len(r)) if len(r)>0 else 0
+        return {"in": r_q_in, "ex": r_q_ex}
 
     def volume(self):
         """Calculate pore volume. This is done by defining a new shape object
@@ -1243,3 +1326,330 @@ class PoreCapsule(PoreSystem):
         props["Cavity separation distance(nm)"] = [form%self._sep, " "]
 
         return self._table_base(props, decimals)
+
+
+class PoreAmorphCylinder(PoreSystem):
+    """This class carves a cylindric pore system out of an amorph
+    :math:`\\beta`-cristobalite block from
+    `Vink et al. <http://doi.org/10.1103/PhysRevB.67.245201>`_ with dimensions
+    [9.605, 9.605, 9.605] (x, y, z).
+
+    Parameters
+    ----------
+    diam : float
+        Cylinder diameter
+    res : float, optional
+        Reservoir size on each side
+    hydro: list, optional
+        Hydroxilation degree for interior and exterior of the pore in
+        :math:`\\frac{\\mu\\text{mol}}{\\text{m}^2}`
+
+    Examples
+    --------
+    Following example generates a cylindrical pore with a diameter of 4nm,
+    reservoirs of 5nm on each side and a surface functionalized with TMS
+
+    .. code-block:: python
+
+        import porems as pms
+
+        pore = pms.PoreAmorphCylinder(4, 5)
+
+        pore.attach(pms.gen.tms(), 0, [0, 1], 100, "in")
+        pore.attach(pms.gen.tms(), 0, [0, 1], 20, "ex")
+
+        pore.finalize()
+
+        pore.store("output/")
+    """
+    def __init__(self, diam, res=5, hydro=[0, 0]):
+        # Call super class
+        super(PoreAmorphCylinder, self).__init__()
+
+        # Initialize
+        self._diam = diam
+        self._res = res
+        self._sort_list = ["OM", "SI"]
+
+        # Build pattern
+        pattern = pms.BetaCristobalit()
+        pattern.generate([2, 2, 2], "z")
+        pattern._structure = pms.Molecule(inp=os.path.split(__file__)[0]+"/templates/amorph.gro")
+        pattern._size = [2.014, 1.751, 2.468]
+
+        # Create block
+        self._block = pattern.get_block()
+        self._block.set_name("pore")
+        self._box = self._block.get_box()
+
+        # Dice up block
+        dice = pms.Dice(self._block, 0.4, True)
+        matrix = pms.Matrix(dice.find_parallel(None, ["Si", "O"], [0.160-0.02, 0.160+0.02]))
+        matrix.split(57790, 2524)
+
+        # Create pore object
+        self._pore = pms.Pore(self._block, matrix)
+        self._pore.set_name("pore")
+
+        # Create exterior
+        if res:
+            self._pore.exterior(pattern.get_gap())
+
+        # Carve out shape
+        self._centroid = self._block.centroid()
+        central = [0, 0, 1]
+        self._cylinder = pms.Cylinder({"centroid": self._centroid, "central": central, "length": 9.605, "diameter": diam-0.5})  # Preperation precaution
+        del_list = [atom_id for atom_id, atom in enumerate(self._block.get_atom_list()) if self._cylinder.is_in(atom.get_pos())]
+        matrix.strip(del_list)
+        self._pore_shape = "CYLINDER"
+
+        # Prepare pore surface
+        self._pore.prepare()
+
+        # Determine sites
+        self._pore.sites()
+        site_list = self._pore.get_sites()
+        self._site_in = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="in"]
+        self._site_ex = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
+
+        # Save original surface si positions
+        self._si_pos_in = [self._block.pos(site_key) for site_key, site_val in site_list.items() if site_val["type"]=="in"]
+        self._si_pos_ex = [self._block.pos(site_key) for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
+
+        # Siloxane bridges
+        if hydro[0]:
+            self._siloxane(hydro[0], "in", [0, 0.51])
+            self._site_in = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="in"]
+        if hydro[1]:
+            self._siloxane(hydro[1], "ex", [0, 0.51])
+            self._site_ex = [site_key for site_key, site_val in site_list.items() if site_val["type"]=="ex"]
+
+        # Objectify grid
+        non_grid = matrix.bound(1)+list(site_list.keys())
+        bonded = matrix.bound(0, "gt")
+        grid_atoms = [atom for atom in bonded if not atom in non_grid]
+        self._pore.objectify(grid_atoms)
+
+
+    ##############
+    # Attachment #
+    ##############
+    def _normal_in(self, pos):
+        """Normal function for the interior surface
+
+        Parameters
+        ----------
+        pos : list
+            Position on the surface
+
+        Returns
+        -------
+        normal : list
+            Vector perpendicular to surface of the given position
+        """
+        return self._cylinder.normal(pos)
+
+    def _normal_ex(self, pos):
+        """Normal function for the exterior surface
+
+        Parameters
+        ----------
+        pos : list
+            Position on the surface
+
+        Returns
+        -------
+        normal : list
+            Vector perpendicular to surface of the given position
+        """
+        return [0, 0, -1] if pos[2] < self._centroid[2] else [0, 0, 1]
+
+    def attach_special(self, mol, mount, axis, amount, scale=1, symmetry="point", is_proxi=True, is_rotate=False):
+        """Special attachment of molecules on the surface.
+
+        Parameters
+        ----------
+        mol : Molecule
+            Molecule object to attach
+        mount : integer
+            Atom id of the molecule that is placed on the surface silicon atom
+        axis : list
+            List of two atom ids of the molecule that define the molecule axis
+        amount : int
+            Number of molecules to attach
+        scale : float, optional
+            Circumference scaling around the molecule position
+        symmetry : string, optional
+            Symmetry option - point, mirror
+        is_proxi : bool, optional
+            True to fill binding sites in proximity of filled binding site
+        is_rotate : bool, optional
+            True to randomly rotate molecule around own axis
+        """
+        # Process input
+        if symmetry not in ["point", "mirror"]:
+            print("Symmetry type not supported...")
+            return
+
+        # Calculate geometrical positions
+        dist = self._box[2]/amount if amount>0 else 0
+        start = dist/2
+
+        pos_list = []
+        for i in range(amount):
+            if symmetry == "point":
+                coeff = -1 if i % 2 == 0 else 1
+            elif symmetry == "mirror":
+                coeff = 1
+
+            x = self._centroid[0]+coeff*self.diameter()/2
+            y = self._centroid[1]
+            z = start+dist*i
+
+            pos_list.append([x, y, z])
+
+        # Run attachment
+        mols = self._pore.attach(mol, mount, axis, self._site_in, len(pos_list), self._normal_in, scale, pos_list=pos_list, is_proxi=is_proxi, is_random=False, is_rotate=is_rotate)
+
+        # Add to sorting list
+        for mol in mols:
+            if not mol.get_short() in self._sort_list:
+                self._sort_list.append(mol.get_short())
+
+
+    ############
+    # Analysis #
+    ############
+    def diameter(self):
+        """Calculate true cylinder diameter after drilling and preperation. This
+        is done by determining the mean value :math:`\\bar r` of the silicon
+        distances :math:`r_i` of silicon :math:`i` towards the pore center
+
+        .. math::
+
+            \\bar r=\\frac1n\\sum_{i=1}^nr_i
+
+        with the number of silicon atoms :math:`n`. The diameter is then
+
+        .. math::
+
+            d=2\\bar r=\\frac2n\\sum_{i=1}^nr_i.
+
+        Returns
+        -------
+        diameter : float
+            Pore diameter after preperation
+        """
+        # Calculate distance towards central axis of binding site silicon atoms
+        r = [pms.geom.length(pms.geom.vector([self._centroid[0], self._centroid[1], pos[2]], pos)) for pos in self._si_pos_in]
+
+        # Calculate mean
+        r_bar = sum(r)/len(r) if len(r)>0 else 0
+
+        # Calculate diameter
+        return 2*r_bar
+
+    def roughness(self):
+        """Calculate surface roughness. In the case of a cylindric pore one can
+        visualize pulling the pore apart, thus flattening the interior surface.
+        The roughness is then determined by calculating the standard deviation
+        of the binding site silicon atoms peaks and valleys.
+
+        It is therefore enough to calculate the distances towards a specific
+        axis, which in this case will be the central axis. The mean value
+        :math:`\\bar r` of the silicon distances :math:`r_i` of silicon
+        :math:`i` towards the pore center, is calculated by
+
+        .. math::
+
+            \\bar r=\\frac1n\\sum_{i=1}^nr_i
+
+        with the number of silicon atoms :math:`n`. This mean value is used in
+        the square root roughness calculation
+
+        .. math::
+
+            R_q = \\sqrt{\\frac1n\\sum_{i=1}^n\\|r_i-\\bar r\\|^2}.
+
+        Returns
+        -------
+        roughness : float
+            Surface roughness
+        """
+        # Interior
+        ## Calculate distance towards central axis of binding site silicon atoms
+        r_in = [pms.geom.length(pms.geom.vector([self._centroid[0], self._centroid[1], pos[2]], pos)) for pos in self._si_pos_in]
+
+        # Exterior
+        if self._res:
+            ## Create molecules with exterior positions
+            temp_mol = pms.Molecule()
+            for pos in self._si_pos_ex:
+                temp_mol.add("Si", pos)
+            temp_mol.zero()
+            size = temp_mol.get_box()[2]
+
+        ## Calculate distance to boundary
+        r_ex = [pos[2] if pos[2] < size/2 else abs(pos[2]-size) for pos in self._si_pos_ex]
+
+        # Calculate mean
+        r_bar_in = sum(r_in)/len(r_in) if len(r_in)>0 else 0
+        r_bar_ex = sum(r_ex)/len(r_ex) if len(r_ex)>0 else 0
+
+        # Calculate roughness
+        r_q_in =  math.sqrt(sum([(r_i-r_bar_in)**2 for r_i in r_in])/len(r_in)) if len(r_in)>0 else 0
+        r_q_ex =  math.sqrt(sum([(r_i-r_bar_ex)**2 for r_i in r_ex])/len(r_ex)) if len(r_ex)>0 else 0
+
+        # Calculate square root roughness
+        return {"in": r_q_in, "ex": r_q_ex}
+
+    def volume(self):
+        """Calculate pore volume. This is done by defining a new shape object
+        with system sizes after pore preparation and using the volume function
+        :func:`porems.shape.Cylinder.volume`.
+
+        Returns
+        -------
+        volume : float
+            Pore volume
+        """
+        return pms.Cylinder({"centroid": self._centroid, "central": [0, 0, 1], "length": self._box[2], "diameter": self.diameter()}).volume()
+
+    def surface(self):
+        """Calculate pore surface and exterior surface. This is done by defining
+        a new shape object with system sizes after pore preparation and using
+        the surface function :func:`porems.shape.Cylinder.surface`.
+
+        Returns
+        -------
+        surface : dictionary
+            Pore surface of interior and exterior
+        """
+        diam = self.diameter()
+
+        surf_in = pms.Cylinder({"centroid": self._centroid, "central": [0, 0, 1], "length": self._box[2], "diameter": diam}).surface()
+        surf_ex = 2*(self._box[0]*self._box[1]-math.pi*(diam/2)**2)
+
+        return {"in": surf_in, "ex": surf_ex}
+
+    def table(self, decimals=3):
+        """Create properties as pandas table for easy viewing.
+
+        Parameters
+        ----------
+        decimals : integer, optional
+            Number of decimals to be rounded to
+
+        Returns
+        -------
+        tables : DataFrame
+            Pandas table of all properties
+        """
+        # Initialize
+        form = "%."+str(decimals)+"f"
+
+        # Define pore specific properties
+        props = {}
+        props["Pore diameter (nm)"] = [form%self.diameter(), " "]
+
+        return self._table_base(props, decimals)
